@@ -3,7 +3,7 @@ package Math::Image::CalcResized;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-23'; # DATE
 our $DIST = 'Math-Image-CalcResized'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,7 +15,7 @@ our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'Calculate resized dimensions of image/video',
+    summary => 'Calculate dimensions of image/video resized by ImageMagick-like geometry specification',
 };
 
 $SPEC{calc_image_resized_size} = {
@@ -217,7 +217,7 @@ sub calc_image_resized_size {
 }
 
 1;
-# ABSTRACT: Calculate resized dimensions of image/video
+# ABSTRACT: Calculate dimensions of image/video resized by ImageMagick-like geometry specification
 
 __END__
 
@@ -227,11 +227,11 @@ __END__
 
 =head1 NAME
 
-Math::Image::CalcResized - Calculate resized dimensions of image/video
+Math::Image::CalcResized - Calculate dimensions of image/video resized by ImageMagick-like geometry specification
 
 =head1 VERSION
 
-This document describes version 0.001 of Math::Image::CalcResized (from Perl distribution Math-Image-CalcResized), released on 2020-09-23.
+This document describes version 0.002 of Math::Image::CalcResized (from Perl distribution Math-Image-CalcResized), released on 2020-09-23.
 
 =head1 FUNCTIONS
 
